Exception: ROBundle::ROError
- Inherits:
-
RuntimeError
- Object
- RuntimeError
- ROBundle::ROError
- Defined in:
- lib/ro-bundle/exceptions.rb
Overview
The base of all exceptions raised by this library.
The base of all exceptions raised by this library.