Module: ROBundle
- Defined in:
- lib/ro-bundle.rb,
lib/ro-bundle/file.rb,
lib/ro-bundle/util.rb,
lib/ro-bundle/version.rb,
lib/ro-bundle/ro/agent.rb,
lib/ro-bundle/ro/proxy.rb,
lib/ro-bundle/exceptions.rb,
lib/ro-bundle/ro/manifest.rb,
lib/ro-bundle/ro/aggregate.rb,
lib/ro-bundle/ro/directory.rb,
lib/ro-bundle/ro/annotation.rb,
lib/ro-bundle/ro/provenance.rb,
lib/ro-bundle/ro/manifest-entry.rb
Overview
This is a ruby library to read and write Research Object Bundle files in PK Zip format. See the ROBundle::File class for more information.
See the RO Bundle specification for more details.
Most of this library’s API is provided by two underlying gems. Please consult their documentation in addition to this:
There are code examples available with the source code of this library.
Defined Under Namespace
Modules: Provenance, Util Classes: Agent, Aggregate, Annotation, File, Manifest, ManifestEntry, Proxy, RODir, ROError
Constant Summary collapse
- VERSION =
The version number of this library as a String.
"0.3.0"